@@ -19,17 +19,13 @@ if TYPE_CHECKING:
 
 
 def _collections_transform():
-    return parse(
-        """
+    return parse("""
     class defaultdict(dict):
         default_factory = None
         def __missing__(self, key): pass
         def __getitem__(self, key): return default_factory
 
-    """
-        + _deque_mock()
-        + _ordered_dict_mock()
-    )
+    """ + _deque_mock() + _ordered_dict_mock())
 
 
 def _collections_abc_313_transform() -> nodes.Module:
