@@ -3,6 +3,7 @@
 # Copyright (c) https://github.com/pylint-dev/astroid/blob/main/CONTRIBUTORS.txt
 
 """Astroid hooks for pytest."""
+
 from astroid import nodes
 from astroid.brain.helpers import register_module_extender
 from astroid.builder import AstroidBuilder
@@ -10,8 +11,7 @@ from astroid.manager import AstroidManager
 
 
 def pytest_transform() -> nodes.Module:
-    return AstroidBuilder(AstroidManager()).string_build(
-        """
+    return AstroidBuilder(AstroidManager()).string_build("""
 
 try:
     import _pytest.mark
@@ -76,8 +76,7 @@ except ImportError:
         yield_fixture = _pytest.python.yield_fixture
     except ImportError:
         pass
-"""
-    )
+""")
 
 
 def register(manager: AstroidManager) -> None:
